# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: applications_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import applications_common_pb2 as applications__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61pplications_service.proto\x12 armonik.api.grpc.v1.applications\x1a\x19\x61pplications_common.proto2\x9c\x01\n\x0c\x41pplications\x12\x8b\x01\n\x10ListApplications\x12\x39.armonik.api.grpc.v1.applications.ListApplicationsRequest\x1a:.armonik.api.grpc.v1.applications.ListApplicationsResponse\"\x00\x42#\xaa\x02 ArmoniK.Api.gRPC.V1.Applicationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'applications_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002 ArmoniK.Api.gRPC.V1.Applications'
  _globals['_APPLICATIONS']._serialized_start=92
  _globals['_APPLICATIONS']._serialized_end=248
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sort_direction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14sort_direction.proto\x12\"armonik.api.grpc.v1.sort_direction*`\n\rSortDirection\x12\x1e\n\x1aSORT_DIRECTION_UNSPECIFIED\x10\x00\x12\x16\n\x12SORT_DIRECTION_ASC\x10\x01\x12\x17\n\x13SORT_DIRECTION_DESC\x10\x02\x42$\xaa\x02!ArmoniK.Api.gRPC.V1.SortDirectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sort_direction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002!ArmoniK.Api.gRPC.V1.SortDirection'
  _globals['_SORTDIRECTION']._serialized_start=60
  _globals['_SORTDIRECTION']._serialized_end=156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: partitions_fields.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17partitions_fields.proto\x12\x1e\x61rmonik.api.grpc.v1.partitions\"Y\n\x11PartitionRawField\x12\x44\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x35.armonik.api.grpc.v1.partitions.PartitionRawEnumField\"k\n\x0ePartitionField\x12P\n\x13partition_raw_field\x18\x01 \x01(\x0b\x32\x31.armonik.api.grpc.v1.partitions.PartitionRawFieldH\x00\x42\x07\n\x05\x66ield*\xc1\x02\n\x15PartitionRawEnumField\x12(\n$PARTITION_RAW_ENUM_FIELD_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPARTITION_RAW_ENUM_FIELD_ID\x10\x01\x12\x31\n-PARTITION_RAW_ENUM_FIELD_PARENT_PARTITION_IDS\x10\x02\x12)\n%PARTITION_RAW_ENUM_FIELD_POD_RESERVED\x10\x03\x12$\n PARTITION_RAW_ENUM_FIELD_POD_MAX\x10\x04\x12\x32\n.PARTITION_RAW_ENUM_FIELD_PREEMPTION_PERCENTAGE\x10\x05\x12%\n!PARTITION_RAW_ENUM_FIELD_PRIORITY\x10\x06\x42!\xaa\x02\x1e\x41rmoniK.Api.gRPC.V1.Partitionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'partitions_fields_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\036ArmoniK.Api.gRPC.V1.Partitions'
  _globals['_PARTITIONRAWENUMFIELD']._serialized_start=260
  _globals['_PARTITIONRAWENUMFIELD']._serialized_end=581
  _globals['_PARTITIONRAWFIELD']._serialized_start=59
  _globals['_PARTITIONRAWFIELD']._serialized_end=148
  _globals['_PARTITIONFIELD']._serialized_start=150
  _globals['_PARTITIONFIELD']._serialized_end=257
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import agent_common_pb2 as agent__common__pb2


class AgentStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateResultsMetaData = channel.unary_unary(
                '/armonik.api.grpc.v1.agent.Agent/CreateResultsMetaData',
                request_serializer=agent__common__pb2.CreateResultsMetaDataRequest.SerializeToString,
                response_deserializer=agent__common__pb2.CreateResultsMetaDataResponse.FromString,
                )
        self.CreateResults = channel.unary_unary(
                '/armonik.api.grpc.v1.agent.Agent/CreateResults',
                request_serializer=agent__common__pb2.CreateResultsRequest.SerializeToString,
                response_deserializer=agent__common__pb2.CreateResultsResponse.FromString,
                )
        self.UploadResultData = channel.stream_unary(
                '/armonik.api.grpc.v1.agent.Agent/UploadResultData',
                request_serializer=agent__common__pb2.UploadResultDataRequest.SerializeToString,
                response_deserializer=agent__common__pb2.UploadResultDataResponse.FromString,
                )
        self.SubmitTasks = channel.unary_unary(
                '/armonik.api.grpc.v1.agent.Agent/SubmitTasks',
                request_serializer=agent__common__pb2.SubmitTasksRequest.SerializeToString,
                response_deserializer=agent__common__pb2.SubmitTasksResponse.FromString,
                )
        self.CreateTask = channel.stream_unary(
                '/armonik.api.grpc.v1.agent.Agent/CreateTask',
                request_serializer=agent__common__pb2.CreateTaskRequest.SerializeToString,
                response_deserializer=agent__common__pb2.CreateTaskReply.FromString,
                )
        self.GetResourceData = channel.unary_stream(
                '/armonik.api.grpc.v1.agent.Agent/GetResourceData',
                request_serializer=agent__common__pb2.DataRequest.SerializeToString,
                response_deserializer=agent__common__pb2.DataReply.FromString,
                )
        self.GetCommonData = channel.unary_stream(
                '/armonik.api.grpc.v1.agent.Agent/GetCommonData',
                request_serializer=agent__common__pb2.DataRequest.SerializeToString,
                response_deserializer=agent__common__pb2.DataReply.FromString,
                )
        self.GetDirectData = channel.unary_stream(
                '/armonik.api.grpc.v1.agent.Agent/GetDirectData',
                request_serializer=agent__common__pb2.DataRequest.SerializeToString,
                response_deserializer=agent__common__pb2.DataReply.FromString,
                )
        self.SendResult = channel.stream_unary(
                '/armonik.api.grpc.v1.agent.Agent/SendResult',
                request_serializer=agent__common__pb2.Result.SerializeToString,
                response_deserializer=agent__common__pb2.ResultReply.FromString,
                )


class AgentServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateResultsMetaData(self, request, context):
        """*
        Create the metadata of multiple results at once
        Data have to be uploaded separately
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateResults(self, request, context):
        """*
        Create one result with data included in the request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadResultData(self, request_iterator, context):
        """*
        Upload data for result with stream
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitTasks(self, request, context):
        """*
        Create tasks metadata and submit task for processing.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTask(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResourceData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommonData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDirectData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendResult(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateResultsMetaData': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateResultsMetaData,
                    request_deserializer=agent__common__pb2.CreateResultsMetaDataRequest.FromString,
                    response_serializer=agent__common__pb2.CreateResultsMetaDataResponse.SerializeToString,
            ),
            'CreateResults': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateResults,
                    request_deserializer=agent__common__pb2.CreateResultsRequest.FromString,
                    response_serializer=agent__common__pb2.CreateResultsResponse.SerializeToString,
            ),
            'UploadResultData': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadResultData,
                    request_deserializer=agent__common__pb2.UploadResultDataRequest.FromString,
                    response_serializer=agent__common__pb2.UploadResultDataResponse.SerializeToString,
            ),
            'SubmitTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitTasks,
                    request_deserializer=agent__common__pb2.SubmitTasksRequest.FromString,
                    response_serializer=agent__common__pb2.SubmitTasksResponse.SerializeToString,
            ),
            'CreateTask': grpc.stream_unary_rpc_method_handler(
                    servicer.CreateTask,
                    request_deserializer=agent__common__pb2.CreateTaskRequest.FromString,
                    response_serializer=agent__common__pb2.CreateTaskReply.SerializeToString,
            ),
            'GetResourceData': grpc.unary_stream_rpc_method_handler(
                    servicer.GetResourceData,
                    request_deserializer=agent__common__pb2.DataRequest.FromString,
                    response_serializer=agent__common__pb2.DataReply.SerializeToString,
            ),
            'GetCommonData': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCommonData,
                    request_deserializer=agent__common__pb2.DataRequest.FromString,
                    response_serializer=agent__common__pb2.DataReply.SerializeToString,
            ),
            'GetDirectData': grpc.unary_stream_rpc_method_handler(
                    servicer.GetDirectData,
                    request_deserializer=agent__common__pb2.DataRequest.FromString,
                    response_serializer=agent__common__pb2.DataReply.SerializeToString,
            ),
            'SendResult': grpc.stream_unary_rpc_method_handler(
                    servicer.SendResult,
                    request_deserializer=agent__common__pb2.Result.FromString,
                    response_serializer=agent__common__pb2.ResultReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.agent.Agent', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Agent(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateResultsMetaData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.agent.Agent/CreateResultsMetaData',
            agent__common__pb2.CreateResultsMetaDataRequest.SerializeToString,
            agent__common__pb2.CreateResultsMetaDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.agent.Agent/CreateResults',
            agent__common__pb2.CreateResultsRequest.SerializeToString,
            agent__common__pb2.CreateResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadResultData(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/armonik.api.grpc.v1.agent.Agent/UploadResultData',
            agent__common__pb2.UploadResultDataRequest.SerializeToString,
            agent__common__pb2.UploadResultDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubmitTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.agent.Agent/SubmitTasks',
            agent__common__pb2.SubmitTasksRequest.SerializeToString,
            agent__common__pb2.SubmitTasksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTask(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/armonik.api.grpc.v1.agent.Agent/CreateTask',
            agent__common__pb2.CreateTaskRequest.SerializeToString,
            agent__common__pb2.CreateTaskReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResourceData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/armonik.api.grpc.v1.agent.Agent/GetResourceData',
            agent__common__pb2.DataRequest.SerializeToString,
            agent__common__pb2.DataReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCommonData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/armonik.api.grpc.v1.agent.Agent/GetCommonData',
            agent__common__pb2.DataRequest.SerializeToString,
            agent__common__pb2.DataReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDirectData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/armonik.api.grpc.v1.agent.Agent/GetDirectData',
            agent__common__pb2.DataRequest.SerializeToString,
            agent__common__pb2.DataReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendResult(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/armonik.api.grpc.v1.agent.Agent/SendResult',
            agent__common__pb2.Result.SerializeToString,
            agent__common__pb2.ResultReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from .helpers import datetime_to_timestamp, timestamp_to_datetime, duration_to_timedelta, timedelta_to_duration, get_task_filter
from .objects import Task, TaskDefinition, TaskOptions, Output, ResultAvailability
from .enumwrapper import HealthCheckStatus, TaskStatus



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import objects_pb2 as objects__pb2
from ..common import submitter_common_pb2 as submitter__common__pb2


class SubmitterStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetServiceConfiguration = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/GetServiceConfiguration',
                request_serializer=objects__pb2.Empty.SerializeToString,
                response_deserializer=objects__pb2.Configuration.FromString,
                )
        self.CreateSession = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/CreateSession',
                request_serializer=submitter__common__pb2.CreateSessionRequest.SerializeToString,
                response_deserializer=submitter__common__pb2.CreateSessionReply.FromString,
                )
        self.CancelSession = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/CancelSession',
                request_serializer=objects__pb2.Session.SerializeToString,
                response_deserializer=objects__pb2.Empty.FromString,
                )
        self.CreateSmallTasks = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/CreateSmallTasks',
                request_serializer=submitter__common__pb2.CreateSmallTaskRequest.SerializeToString,
                response_deserializer=submitter__common__pb2.CreateTaskReply.FromString,
                )
        self.CreateLargeTasks = channel.stream_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/CreateLargeTasks',
                request_serializer=submitter__common__pb2.CreateLargeTaskRequest.SerializeToString,
                response_deserializer=submitter__common__pb2.CreateTaskReply.FromString,
                )
        self.ListTasks = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/ListTasks',
                request_serializer=submitter__common__pb2.TaskFilter.SerializeToString,
                response_deserializer=objects__pb2.TaskIdList.FromString,
                )
        self.ListSessions = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/ListSessions',
                request_serializer=submitter__common__pb2.SessionFilter.SerializeToString,
                response_deserializer=submitter__common__pb2.SessionIdList.FromString,
                )
        self.CountTasks = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/CountTasks',
                request_serializer=submitter__common__pb2.TaskFilter.SerializeToString,
                response_deserializer=objects__pb2.Count.FromString,
                )
        self.TryGetResultStream = channel.unary_stream(
                '/armonik.api.grpc.v1.submitter.Submitter/TryGetResultStream',
                request_serializer=objects__pb2.ResultRequest.SerializeToString,
                response_deserializer=submitter__common__pb2.ResultReply.FromString,
                )
        self.TryGetTaskOutput = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/TryGetTaskOutput',
                request_serializer=objects__pb2.TaskOutputRequest.SerializeToString,
                response_deserializer=objects__pb2.Output.FromString,
                )
        self.WaitForAvailability = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/WaitForAvailability',
                request_serializer=objects__pb2.ResultRequest.SerializeToString,
                response_deserializer=submitter__common__pb2.AvailabilityReply.FromString,
                )
        self.WaitForCompletion = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/WaitForCompletion',
                request_serializer=submitter__common__pb2.WaitRequest.SerializeToString,
                response_deserializer=objects__pb2.Count.FromString,
                )
        self.CancelTasks = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/CancelTasks',
                request_serializer=submitter__common__pb2.TaskFilter.SerializeToString,
                response_deserializer=objects__pb2.Empty.FromString,
                )
        self.GetTaskStatus = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/GetTaskStatus',
                request_serializer=submitter__common__pb2.GetTaskStatusRequest.SerializeToString,
                response_deserializer=submitter__common__pb2.GetTaskStatusReply.FromString,
                )
        self.GetResultStatus = channel.unary_unary(
                '/armonik.api.grpc.v1.submitter.Submitter/GetResultStatus',
                request_serializer=submitter__common__pb2.GetResultStatusRequest.SerializeToString,
                response_deserializer=submitter__common__pb2.GetResultStatusReply.FromString,
                )
        self.WatchResults = channel.stream_stream(
                '/armonik.api.grpc.v1.submitter.Submitter/WatchResults',
                request_serializer=submitter__common__pb2.WatchResultRequest.SerializeToString,
                response_deserializer=submitter__common__pb2.WatchResultStream.FromString,
                )


class SubmitterServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetServiceConfiguration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSmallTasks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLargeTasks(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTasks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSessions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CountTasks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TryGetResultStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TryGetTaskOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WaitForAvailability(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WaitForCompletion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelTasks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResultStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchResults(self, request_iterator, context):
        """*
        This endpoint allows a user to watch a list of results and be notified when there is any change.
        The user sends the list of ids they want to watch.
        The submitter will then send the statuses for all requested ids immediately and keep the stream open.
        Ids not present in DB will be returned at that time with the special state NOTFOUND.
        The submitter will send updates to the client via the opened stream.
        Any reply can be implicitely chunked if there are too many event to report at the same time (or for the first reply).
        It is possible to filter out specific statuses from events.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SubmitterServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetServiceConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceConfiguration,
                    request_deserializer=objects__pb2.Empty.FromString,
                    response_serializer=objects__pb2.Configuration.SerializeToString,
            ),
            'CreateSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSession,
                    request_deserializer=submitter__common__pb2.CreateSessionRequest.FromString,
                    response_serializer=submitter__common__pb2.CreateSessionReply.SerializeToString,
            ),
            'CancelSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelSession,
                    request_deserializer=objects__pb2.Session.FromString,
                    response_serializer=objects__pb2.Empty.SerializeToString,
            ),
            'CreateSmallTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSmallTasks,
                    request_deserializer=submitter__common__pb2.CreateSmallTaskRequest.FromString,
                    response_serializer=submitter__common__pb2.CreateTaskReply.SerializeToString,
            ),
            'CreateLargeTasks': grpc.stream_unary_rpc_method_handler(
                    servicer.CreateLargeTasks,
                    request_deserializer=submitter__common__pb2.CreateLargeTaskRequest.FromString,
                    response_serializer=submitter__common__pb2.CreateTaskReply.SerializeToString,
            ),
            'ListTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTasks,
                    request_deserializer=submitter__common__pb2.TaskFilter.FromString,
                    response_serializer=objects__pb2.TaskIdList.SerializeToString,
            ),
            'ListSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSessions,
                    request_deserializer=submitter__common__pb2.SessionFilter.FromString,
                    response_serializer=submitter__common__pb2.SessionIdList.SerializeToString,
            ),
            'CountTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.CountTasks,
                    request_deserializer=submitter__common__pb2.TaskFilter.FromString,
                    response_serializer=objects__pb2.Count.SerializeToString,
            ),
            'TryGetResultStream': grpc.unary_stream_rpc_method_handler(
                    servicer.TryGetResultStream,
                    request_deserializer=objects__pb2.ResultRequest.FromString,
                    response_serializer=submitter__common__pb2.ResultReply.SerializeToString,
            ),
            'TryGetTaskOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.TryGetTaskOutput,
                    request_deserializer=objects__pb2.TaskOutputRequest.FromString,
                    response_serializer=objects__pb2.Output.SerializeToString,
            ),
            'WaitForAvailability': grpc.unary_unary_rpc_method_handler(
                    servicer.WaitForAvailability,
                    request_deserializer=objects__pb2.ResultRequest.FromString,
                    response_serializer=submitter__common__pb2.AvailabilityReply.SerializeToString,
            ),
            'WaitForCompletion': grpc.unary_unary_rpc_method_handler(
                    servicer.WaitForCompletion,
                    request_deserializer=submitter__common__pb2.WaitRequest.FromString,
                    response_serializer=objects__pb2.Count.SerializeToString,
            ),
            'CancelTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelTasks,
                    request_deserializer=submitter__common__pb2.TaskFilter.FromString,
                    response_serializer=objects__pb2.Empty.SerializeToString,
            ),
            'GetTaskStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskStatus,
                    request_deserializer=submitter__common__pb2.GetTaskStatusRequest.FromString,
                    response_serializer=submitter__common__pb2.GetTaskStatusReply.SerializeToString,
            ),
            'GetResultStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResultStatus,
                    request_deserializer=submitter__common__pb2.GetResultStatusRequest.FromString,
                    response_serializer=submitter__common__pb2.GetResultStatusReply.SerializeToString,
            ),
            'WatchResults': grpc.stream_stream_rpc_method_handler(
                    servicer.WatchResults,
                    request_deserializer=submitter__common__pb2.WatchResultRequest.FromString,
                    response_serializer=submitter__common__pb2.WatchResultStream.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.submitter.Submitter', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Submitter(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetServiceConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/GetServiceConfiguration',
            objects__pb2.Empty.SerializeToString,
            objects__pb2.Configuration.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/CreateSession',
            submitter__common__pb2.CreateSessionRequest.SerializeToString,
            submitter__common__pb2.CreateSessionReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/CancelSession',
            objects__pb2.Session.SerializeToString,
            objects__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSmallTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/CreateSmallTasks',
            submitter__common__pb2.CreateSmallTaskRequest.SerializeToString,
            submitter__common__pb2.CreateTaskReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateLargeTasks(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/armonik.api.grpc.v1.submitter.Submitter/CreateLargeTasks',
            submitter__common__pb2.CreateLargeTaskRequest.SerializeToString,
            submitter__common__pb2.CreateTaskReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/ListTasks',
            submitter__common__pb2.TaskFilter.SerializeToString,
            objects__pb2.TaskIdList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/ListSessions',
            submitter__common__pb2.SessionFilter.SerializeToString,
            submitter__common__pb2.SessionIdList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CountTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/CountTasks',
            submitter__common__pb2.TaskFilter.SerializeToString,
            objects__pb2.Count.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TryGetResultStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/armonik.api.grpc.v1.submitter.Submitter/TryGetResultStream',
            objects__pb2.ResultRequest.SerializeToString,
            submitter__common__pb2.ResultReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TryGetTaskOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/TryGetTaskOutput',
            objects__pb2.TaskOutputRequest.SerializeToString,
            objects__pb2.Output.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WaitForAvailability(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/WaitForAvailability',
            objects__pb2.ResultRequest.SerializeToString,
            submitter__common__pb2.AvailabilityReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WaitForCompletion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/WaitForCompletion',
            submitter__common__pb2.WaitRequest.SerializeToString,
            objects__pb2.Count.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/CancelTasks',
            submitter__common__pb2.TaskFilter.SerializeToString,
            objects__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTaskStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/GetTaskStatus',
            submitter__common__pb2.GetTaskStatusRequest.SerializeToString,
            submitter__common__pb2.GetTaskStatusReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResultStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.submitter.Submitter/GetResultStatus',
            submitter__common__pb2.GetResultStatusRequest.SerializeToString,
            submitter__common__pb2.GetResultStatusReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchResults(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/armonik.api.grpc.v1.submitter.Submitter/WatchResults',
            submitter__common__pb2.WatchResultRequest.SerializeToString,
            submitter__common__pb2.WatchResultStream.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from . import applications_fields_pb2 as _applications_fields_pb2
from . import applications_filters_pb2 as _applications_filters_pb2
from . import sort_direction_pb2 as _sort_direction_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApplicationRaw(_message.Message):
    __slots__ = ["name", "version", "namespace", "service"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: str
    namespace: str
    service: str
    def __init__(self, name: _Optional[str] = ..., version: _Optional[str] = ..., namespace: _Optional[str] = ..., service: _Optional[str] = ...) -> None: ...

class ListApplicationsRequest(_message.Message):
    __slots__ = ["page", "page_size", "filters", "sort"]
    class Sort(_message.Message):
        __slots__ = ["fields", "direction"]
        FIELDS_FIELD_NUMBER: _ClassVar[int]
        DIRECTION_FIELD_NUMBER: _ClassVar[int]
        fields: _containers.RepeatedCompositeFieldContainer[_applications_fields_pb2.ApplicationField]
        direction: _sort_direction_pb2.SortDirection
        def __init__(self, fields: _Optional[_Iterable[_Union[_applications_fields_pb2.ApplicationField, _Mapping]]] = ..., direction: _Optional[_Union[_sort_direction_pb2.SortDirection, str]] = ...) -> None: ...
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    page: int
    page_size: int
    filters: _applications_filters_pb2.Filters
    sort: ListApplicationsRequest.Sort
    def __init__(self, page: _Optional[int] = ..., page_size: _Optional[int] = ..., filters: _Optional[_Union[_applications_filters_pb2.Filters, _Mapping]] = ..., sort: _Optional[_Union[ListApplicationsRequest.Sort, _Mapping]] = ...) -> None: ...

class ListApplicationsResponse(_message.Message):
    __slots__ = ["applications", "page", "page_size", "total"]
    APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    applications: _containers.RepeatedCompositeFieldContainer[ApplicationRaw]
    page: int
    page_size: int
    total: int
    def __init__(self, applications: _Optional[_Iterable[_Union[ApplicationRaw, _Mapping]]] = ..., page: _Optional[int] = ..., page_size: _Optional[int] = ..., total: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: events_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import result_status_pb2 as result__status__pb2
from . import task_status_pb2 as task__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x65vents_common.proto\x12\x1a\x61rmonik.api.grpc.v1.events\x1a\x13result_status.proto\x1a\x11task_status.proto\".\n\x18\x45ventSubscriptionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\xa5\t\n\x19\x45ventSubscriptionResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x64\n\x12task_status_update\x18\x02 \x01(\x0b\x32\x46.armonik.api.grpc.v1.events.EventSubscriptionResponse.TaskStatusUpdateH\x00\x12h\n\x14result_status_update\x18\x03 \x01(\x0b\x32H.armonik.api.grpc.v1.events.EventSubscriptionResponse.ResultStatusUpdateH\x00\x12\x66\n\x13result_owner_update\x18\x04 \x01(\x0b\x32G.armonik.api.grpc.v1.events.EventSubscriptionResponse.ResultOwnerUpdateH\x00\x12Q\n\x08new_task\x18\x05 \x01(\x0b\x32=.armonik.api.grpc.v1.events.EventSubscriptionResponse.NewTaskH\x00\x12U\n\nnew_result\x18\x06 \x01(\x0b\x32?.armonik.api.grpc.v1.events.EventSubscriptionResponse.NewResultH\x00\x1a`\n\x10TaskStatusUpdate\x12\x0f\n\x07task_id\x18\n \x01(\t\x12;\n\x06status\x18\x0b \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x1ah\n\x12ResultStatusUpdate\x12\x11\n\tresult_id\x18\x14 \x01(\t\x12?\n\x06status\x18\x15 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x1a[\n\x11ResultOwnerUpdate\x12\x11\n\tresult_id\x18\x1e \x01(\t\x12\x19\n\x11previous_owner_id\x18\x1f \x01(\t\x12\x18\n\x10\x63urrent_owner_id\x18  \x01(\t\x1a\xeb\x01\n\x07NewTask\x12\x0f\n\x07task_id\x18( \x01(\t\x12\x12\n\npayload_id\x18) \x01(\t\x12\x16\n\x0eorigin_task_id\x18* \x01(\t\x12;\n\x06status\x18+ \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x1c\n\x14\x65xpected_output_keys\x18, \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18- \x03(\t\x12\x14\n\x0cretry_of_ids\x18. \x03(\t\x12\x17\n\x0fparent_task_ids\x18/ \x03(\t\x1aq\n\tNewResult\x12\x11\n\tresult_id\x18\x32 \x01(\t\x12\x10\n\x08owner_id\x18\x33 \x01(\t\x12?\n\x06status\x18\x34 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatusB\x08\n\x06updateB\x1d\xaa\x02\x1a\x41rmoniK.Api.gRPC.V1.Eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'events_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\032ArmoniK.Api.gRPC.V1.Events'
  _globals['_EVENTSUBSCRIPTIONREQUEST']._serialized_start=91
  _globals['_EVENTSUBSCRIPTIONREQUEST']._serialized_end=137
  _globals['_EVENTSUBSCRIPTIONRESPONSE']._serialized_start=140
  _globals['_EVENTSUBSCRIPTIONRESPONSE']._serialized_end=1329
  _globals['_EVENTSUBSCRIPTIONRESPONSE_TASKSTATUSUPDATE']._serialized_start=671
  _globals['_EVENTSUBSCRIPTIONRESPONSE_TASKSTATUSUPDATE']._serialized_end=767
  _globals['_EVENTSUBSCRIPTIONRESPONSE_RESULTSTATUSUPDATE']._serialized_start=769
  _globals['_EVENTSUBSCRIPTIONRESPONSE_RESULTSTATUSUPDATE']._serialized_end=873
  _globals['_EVENTSUBSCRIPTIONRESPONSE_RESULTOWNERUPDATE']._serialized_start=875
  _globals['_EVENTSUBSCRIPTIONRESPONSE_RESULTOWNERUPDATE']._serialized_end=966
  _globals['_EVENTSUBSCRIPTIONRESPONSE_NEWTASK']._serialized_start=969
  _globals['_EVENTSUBSCRIPTIONRESPONSE_NEWTASK']._serialized_end=1204
  _globals['_EVENTSUBSCRIPTIONRESPONSE_NEWRESULT']._serialized_start=1206
  _globals['_EVENTSUBSCRIPTIONRESPONSE_NEWRESULT']._serialized_end=1319
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: worker_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import objects_pb2 as objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13worker_common.proto\x12\x1a\x61rmonik.api.grpc.v1.worker\x1a\robjects.proto\"\xde\x05\n\x0eProcessRequest\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12J\n\x07\x63ompute\x18\x02 \x01(\x0b\x32\x39.armonik.api.grpc.v1.worker.ProcessRequest.ComputeRequest\x1a\xe2\x04\n\x0e\x43omputeRequest\x12]\n\x0cinit_request\x18\x01 \x01(\x0b\x32\x45.armonik.api.grpc.v1.worker.ProcessRequest.ComputeRequest.InitRequestH\x00\x12\x31\n\x07payload\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12W\n\tinit_data\x18\x03 \x01(\x0b\x32\x42.armonik.api.grpc.v1.worker.ProcessRequest.ComputeRequest.InitDataH\x00\x12.\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x1a\xf4\x01\n\x0bInitRequest\x12\x39\n\rconfiguration\x18\x01 \x01(\x0b\x32\".armonik.api.grpc.v1.Configuration\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x0f\n\x07task_id\x18\x03 \x01(\t\x12\x36\n\x0ctask_options\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12\x1c\n\x14\x65xpected_output_keys\x18\x05 \x03(\t\x12/\n\x07payload\x18\x06 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunk\x1a\x36\n\x08InitData\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x13\n\tlast_data\x18\x02 \x01(\x08H\x00\x42\x06\n\x04typeB\x06\n\x04type\"X\n\x0cProcessReply\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12+\n\x06output\x18\x02 \x01(\x0b\x32\x1b.armonik.api.grpc.v1.Output\"\x9a\x01\n\x10HealthCheckReply\x12J\n\x06status\x18\x01 \x01(\x0e\x32:.armonik.api.grpc.v1.worker.HealthCheckReply.ServingStatus\":\n\rServingStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x12\x0f\n\x0bNOT_SERVING\x10\x02\x42\x1d\xaa\x02\x1a\x41rmoniK.Api.gRPC.V1.Workerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'worker_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\032ArmoniK.Api.gRPC.V1.Worker'
  _globals['_PROCESSREQUEST']._serialized_start=67
  _globals['_PROCESSREQUEST']._serialized_end=801
  _globals['_PROCESSREQUEST_COMPUTEREQUEST']._serialized_start=191
  _globals['_PROCESSREQUEST_COMPUTEREQUEST']._serialized_end=801
  _globals['_PROCESSREQUEST_COMPUTEREQUEST_INITREQUEST']._serialized_start=493
  _globals['_PROCESSREQUEST_COMPUTEREQUEST_INITREQUEST']._serialized_end=737
  _globals['_PROCESSREQUEST_COMPUTEREQUEST_INITDATA']._serialized_start=739
  _globals['_PROCESSREQUEST_COMPUTEREQUEST_INITDATA']._serialized_end=793
  _globals['_PROCESSREPLY']._serialized_start=803
  _globals['_PROCESSREPLY']._serialized_end=891
  _globals['_HEALTHCHECKREPLY']._serialized_start=894
  _globals['_HEALTHCHECKREPLY']._serialized_end=1048
  _globals['_HEALTHCHECKREPLY_SERVINGSTATUS']._serialized_start=990
  _globals['_HEALTHCHECKREPLY_SERVINGSTATUS']._serialized_end=1048
# @@protoc_insertion_point(module_scope)
